==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EnhancedDynamicNetworkZoneAllOfLocations.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EnhancedDynamicNetworkZoneAllOfLocationsExclude;
import com.okta.sdk.resource.model.EnhancedDynamicNetworkZoneAllOfLocationsInclude;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * &lt;div class&#x3D;\&quot;x-lifecycle-container\&quot;&gt;&lt;x-lifecycle
 * class&#x3D;\&quot;ea\&quot;&gt;&lt;/x-lifecycle&gt;&lt;/div&gt;The list of geolocations to include or exclude for an
 * Enhanced Dynamic Network Zone
 */
@ApiModel(description = "<div class=\"x-lifecycle-container\"><x-lifecycle class=\"ea\"></x-lifecycle></div>The list of geolocations to include or exclude for an Enhanced Dynamic Network Zone")
@JsonPropertyOrder({ EnhancedDynamicNetworkZoneAllOfLocations.JSON_PROPERTY_INCLUDE,
        EnhancedDynamicNetworkZoneAllOfLocations.JSON_PROPERTY_EXCLUDE })
@JsonTypeName("EnhancedDynamicNetworkZone_allOf_locations")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EnhancedDynamicNetworkZoneAllOfLocations implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private EnhancedDynamicNetworkZoneAllOfLocationsInclude include;

    public static final String JSON_PROPERTY_EXCLUDE = "exclude";
    private EnhancedDynamicNetworkZoneAllOfLocationsExclude exclude;

    public EnhancedDynamicNetworkZoneAllOfLocations() {
    }

    public EnhancedDynamicNetworkZoneAllOfLocations include(EnhancedDynamicNetworkZoneAllOfLocationsInclude include) {

        this.include = include;
        return this;
    }

    /**
     * Get include
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EnhancedDynamicNetworkZoneAllOfLocationsInclude getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(EnhancedDynamicNetworkZoneAllOfLocationsInclude include) {
        this.include = include;
    }

    public EnhancedDynamicNetworkZoneAllOfLocations exclude(EnhancedDynamicNetworkZoneAllOfLocationsExclude exclude) {

        this.exclude = exclude;
        return this;
    }

    /**
     * Get exclude
     *
     * @return exclude
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EnhancedDynamicNetworkZoneAllOfLocationsExclude getExclude() {
        return exclude;
    }

    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExclude(EnhancedDynamicNetworkZoneAllOfLocationsExclude exclude) {
        this.exclude = exclude;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EnhancedDynamicNetworkZoneAllOfLocations enhancedDynamicNetworkZoneAllOfLocations = (EnhancedDynamicNetworkZoneAllOfLocations) o;
        return Objects.equals(this.include, enhancedDynamicNetworkZoneAllOfLocations.include)
                && Objects.equals(this.exclude, enhancedDynamicNetworkZoneAllOfLocations.exclude);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(include, exclude);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EnhancedDynamicNetworkZoneAllOfLocations {\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("    exclude: ").append(toIndentedString(exclude)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EnhancedDynamicNetworkZoneAllOfLocations.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EnhancedDynamicNetworkZoneAllOfLocationsExclude;
import com.okta.sdk.resource.model.EnhancedDynamicNetworkZoneAllOfLocationsInclude;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * &lt;div class&#x3D;\&quot;x-lifecycle-container\&quot;&gt;&lt;x-lifecycle
 * class&#x3D;\&quot;ea\&quot;&gt;&lt;/x-lifecycle&gt;&lt;/div&gt;The list of geolocations to include or exclude for an
 * Enhanced Dynamic Network Zone
 */
@ApiModel(description = "<div class=\"x-lifecycle-container\"><x-lifecycle class=\"ea\"></x-lifecycle></div>The list of geolocations to include or exclude for an Enhanced Dynamic Network Zone")
@JsonPropertyOrder({ EnhancedDynamicNetworkZoneAllOfLocations.JSON_PROPERTY_INCLUDE,
        EnhancedDynamicNetworkZoneAllOfLocations.JSON_PROPERTY_EXCLUDE })
@JsonTypeName("EnhancedDynamicNetworkZone_allOf_locations")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EnhancedDynamicNetworkZoneAllOfLocations implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private EnhancedDynamicNetworkZoneAllOfLocationsInclude include;

    public static final String JSON_PROPERTY_EXCLUDE = "exclude";
    private EnhancedDynamicNetworkZoneAllOfLocationsExclude exclude;

    public EnhancedDynamicNetworkZoneAllOfLocations() {
    }

    public EnhancedDynamicNetworkZoneAllOfLocations include(EnhancedDynamicNetworkZoneAllOfLocationsInclude include) {

        this.include = include;
        return this;
    }

    /**
     * Get include
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EnhancedDynamicNetworkZoneAllOfLocationsInclude getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(EnhancedDynamicNetworkZoneAllOfLocationsInclude include) {
        this.include = include;
    }

    public EnhancedDynamicNetworkZoneAllOfLocations exclude(EnhancedDynamicNetworkZoneAllOfLocationsExclude exclude) {

        this.exclude = exclude;
        return this;
    }

    /**
     * Get exclude
     *
     * @return exclude
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EnhancedDynamicNetworkZoneAllOfLocationsExclude getExclude() {
        return exclude;
    }

    @JsonProperty(JSON_PROPERTY_EXCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setExclude(EnhancedDynamicNetworkZoneAllOfLocationsExclude exclude) {
        this.exclude = exclude;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EnhancedDynamicNetworkZoneAllOfLocations enhancedDynamicNetworkZoneAllOfLocations = (EnhancedDynamicNetworkZoneAllOfLocations) o;
        return Objects.equals(this.include, enhancedDynamicNetworkZoneAllOfLocations.include)
                && Objects.equals(this.exclude, enhancedDynamicNetworkZoneAllOfLocations.exclude);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(include, exclude);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EnhancedDynamicNetworkZoneAllOfLocations {\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("    exclude: ").append(toIndentedString(exclude)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
